@@ -139,7 +139,7 @@ class Teleinfo:
             raise NotImplemented()
         return self.__process_history_frame()
 
-    def read_frame(self):
+    async def read_frame(self):
         """Read a frame from serial port. """
         self.__wait_rcv_frame_start()
         frame = self.__process_frame()
